From d058675b9a4274336ae3497914d6651f653ccde0 Mon Sep 17 00:00:00 2001
From: Alexandru Avadanii <Alexandru.Avadanii@enea.com>
Date: Thu, 26 Oct 2017 19:22:19 +0200
Subject: AArch64: Switch jumpserver VMs to virtio video

Drop vgabios dependency by switching video from VGA to virtio for
all VMs spawned on the jumpserver.

NOTE: This requires virtualization packages on the jumpserver to be
up to date (e.g. libvirt, QEMU).

JIRA: ARMBAND-306

Change-Id: I73913e1ae8584f4e73b92994f78f7ec363cba3ec
Signed-off-by: Alexandru Avadanii <Alexandru.Avadanii@enea.com>
---
 mcp/scripts/lib.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'mcp/scripts')

diff --git a/mcp/scripts/lib.sh b/mcp/scripts/lib.sh
index a165bb367..b8991534b 100644
--- a/mcp/scripts/lib.sh
+++ b/mcp/scripts/lib.sh
@@ -97,8 +97,8 @@ function create_vms {
   # AArch64: prepare arch specific arguments
   local virt_extra_args=""
   if [ "$(uname -i)" = "aarch64" ]; then
-    # No Cirrus VGA on AArch64, use vga std
-    virt_extra_args="$virt_extra_args --video=vga"
+    # No Cirrus VGA on AArch64, use virtio instead
+    virt_extra_args="$virt_extra_args --video=virtio"
   fi
 
   # create vms with specified options
-- 
cgit